@@ -1,5 +1,6 @@
 """Extension utilities."""
 import importlib
+import time
 import warnings
 
 
@@ -35,20 +36,24 @@ def get_loader(obj, logger=None):
     underscore prefix.
     """
     try:
-        func = getattr(obj, "_load_jupyter_server_extension")  # noqa B009
+        return getattr(obj, "_load_jupyter_server_extension")  # noqa B009
+    except AttributeError:
+        pass
+
+    try:
+        func = getattr(obj, "load_jupyter_server_extension")  # noqa B009
     except AttributeError:
-        func = getattr(obj, "load_jupyter_server_extension", None)
-        warnings.warn(
-            "A `_load_jupyter_server_extension` function was not "
-            "found in {name!s}. Instead, a `load_jupyter_server_extension` "
-            "function was found and will be used for now. This function "
-            "name will be deprecated in future releases "
-            "of Jupyter Server.".format(name=obj),
-            DeprecationWarning,
-        )
-    except Exception:
         msg = "_load_jupyter_server_extension function was not found."
         raise ExtensionLoadingError(msg) from None
+
+    warnings.warn(
+        "A `_load_jupyter_server_extension` function was not "
+        "found in {name!s}. Instead, a `load_jupyter_server_extension` "
+        "function was found and will be used for now. This function "
+        "name will be deprecated in future releases "
+        "of Jupyter Server.".format(name=obj),
+        DeprecationWarning,
+    )
     return func
 
 
@@ -62,7 +67,15 @@ def get_metadata(package_name, logger=None):
     If it doesn't exist, return a basic metadata packet given
     the module name.
     """
+    start_time = time.perf_counter()
     module = importlib.import_module(package_name)
+    end_time = time.perf_counter()
+    duration = end_time - start_time
+    # Sometimes packages can take a *while* to import, so we report how long
+    # each module took to import. This makes it much easier for users to report
+    # slow loading modules upstream, as slow loading modules will block server startup
+    if logger:
+        logger.info(f"Package {package_name} took {duration:.4f}s to import")
 
     try:
         return module, module._jupyter_server_extension_points()
